@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: persistent-sqlite
 version: 2.2.1
-id: persistent-sqlite-2.2.1-dc9bfdc32ca418df4843126baeec4677
-key: persi_CzOhGNVDsIQA5jTiizBvHM
+id: persistent-sqlite-2.2.1-c4c06f88bbd417989701992893492a53
+key: persi_FRwzzHoi5teJLTgHkBZxLS
 license: MIT
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
@@ -20,7 +20,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-sqlite-2.2.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-sqlite-2.2.1
-hs-libraries: HSpersistent-sqlite-2.2.1-CzOhGNVDsIQA5jTiizBvHM
+hs-libraries: HSpersistent-sqlite-2.2.1-FRwzzHoi5teJLTgHkBZxLS
 extra-libraries:
     pthread
 depends:
@@ -30,9 +30,9 @@ depends:
     conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
-    monad-logger-0.3.18-868f3e43db7b68548caca5548a3e26c4
+    monad-logger-0.3.18-f3d00babf6bfa7ff698db362dc267041
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    persistent-2.2.4.1-02dc8ce19066ae402489fff269c627fe
+    persistent-2.2.4.1-d8d907c8c62628a6667ab3fa39fc892f
     resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
